TrackerOfflineCalibration

Struct TrackerOfflineCalibration 

pub struct TrackerOfflineCalibration {
    pub mask_map: HashMap<u32, TrackerStripMask>,
    pub tf_map: HashMap<u32, TrackerStripTransferFunction>,
    pub ped_map: HashMap<u32, TrackerStripPedestal>,
    pub gain_map: HashMap<u32, TrackerStripGain>,
    pub pulse_map: HashMap<u32, TrackerStripPulse>,
    pub adc_sig_cut: HashMap<u32, f32>,
    pub remove_cmn: bool,
    pub ped_sigma_cut: f32,
    pub remove_pulsed: bool,
}

Fields

mask_map: HashMap<u32, TrackerStripMask>tf_map: HashMap<u32, TrackerStripTransferFunction>ped_map: HashMap<u32, TrackerStripPedestal>gain_map: HashMap<u32, TrackerStripGain>pulse_map: HashMap<u32, TrackerStripPulse>adc_sig_cut: HashMap<u32, f32>remove_cmn: boolped_sigma_cut: f32remove_pulsed: bool

Implementations

Source

impl TrackerOfflineCalibration

pub fn new() -> Self

pub fn get_common_noise( &self, hit: &TrackerHit, event_hits: &Vec<TrackerHit>, ) -> (f32, bool)

Calculate the common noise level, according to the research of the GAPS tracker group

General scheme is to find the pulsed channel on the strip, get the pulse value, subtract the pedestal and subtract it from the hit adc (taking gain into account)

pub fn mask_hits(&self, event_hits: &mut Vec<TrackerHit>)

pub fn calibrate_event( &self, event: &mut TelemetryEvent, ) -> Result<(), CalibrationError>

pub fn calibrate( &self, event_hits: &mut Vec<TrackerHit>, ) -> Result<(), CalibrationError>

The actual energy calibration of the individual tracker strips

This is a multistep process which includes

  1. Pedestal subtraction
  2. Common noise reduction (if so desired)
  3. ADC -> Energy (Transfer functions)
  4. Deal with strips which had the pulser active

While this might not be the best way to do things, this function matches the implementation in SimpleDet very closely and produces the same results.

See also the compontents in the database related part of this code.